import os
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton
from configparser import ConfigParser


class PriceCore(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        conf = ConfigParser()
        conf.read(os.path.join(self.serviceDir, 'config.ini'))
        self.servicePath = conf.get('pricecore', 'path') if conf.has_option('pricecore', 'path') else '/pricecore'
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post(os.path.join(self.servicePath, 'cart/create'), handler=self.cartCreate),
                web.post(os.path.join(self.servicePath, 'cart/{cartUuid}/add_customer'), handler=self.addCustomer),
                web.post(os.path.join(self.servicePath, 'cart/{cartUuid}/update'), handler=self.cartUpdate),
                web.post(os.path.join(self.servicePath, 'cart/{cartUuid}/cart_status'), handler=self.cartStatus),
                web.post(os.path.join(self.servicePath, 'till/close'), handler=self.tillClose),
                web.post(os.path.join(self.servicePath, 'till/open'), handler=self.tillOpen)]

    async def cartCreate(self, request: web.Request) -> web.Response:
        self.log.info("Создание корзины")
        return self._createResponse(request.path)

    async def addCustomer(self, request: web.Request) -> web.Response:
        self.log.info(f"Добавление клиента в корзину '{request.match_info['cartUuid']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else 'cart/<cartUuid>/add_customer')

    async def cartUpdate(self, request: web.Request) -> web.Response:
        self.log.info(f"Обновление корзины '{request.match_info['cartUuid']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else 'cart/<cartUuid>/update')

    async def cartStatus(self, request: web.Request) -> web.Response:
        self.log.info(f"Изменение статуса корзины '{request.match_info['cartUuid']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else 'cart/<cartUuid>/cart_status')

    async def tillClose(self, request: web.Request) -> web.Response:
        self.log.info("Закрытие смены")
        return self._createResponse(request.path)

    async def tillOpen(self, request: web.Request) -> web.Response:
        self.log.info("Открытие смены")
        return self._createResponse(request.path)


instance = PriceCore()
